@@ -58,7 +58,7 @@ def ajustement_lineaire(x, y, a_p0=1, plot_axes=None, plot_xmin=None, plot_xmax=
         if return_line==True:
             return a[0], line[0]
 
-    return a
+    return a[0]
 
 
 
